@@ -565,14 +565,20 @@ class HTTPPasswordHandler(object):
           (so prefix matching works properly)
 
         Returns url, user, password
-        where url is mercurial.util.url object already stripped of all those
-        params.
+        where url is mercurial.utils.urlutil.url object already stripped of all
+        those params.
         """
         # In case of py3, util.url expects bytes
         authuri = meu.pycompat.bytestr(authuri)
 
         # mercurial.util.url, rather handy url parser
-        parsed_url = util.url(authuri)
+        try:
+            from mercurial.utils import urlutil
+            parsed_url = urlutil.url(authuri)
+        except (AttributeError, ImportError):
+            # hg < 75fc2537d93c (landed in 6.1)
+            parsed_url = util.url(authuri)
+
         parsed_url.query = b''
         parsed_url.fragment = None
         # Strip arguments to get actual remote repository url.
@@ -726,7 +732,17 @@ def keyring_supported_smtp(ui, username):
         defaultport = 465
     else:
         defaultport = 25
-    mailport = util.getport(ui.config(b'smtp', b'port', defaultport))
+
+    try:
+        from mercurial.utils import urlutil
+
+        getport = urlutil.getport
+    except (AttributeError, ImportError):
+        # hg < 75fc2537d93c (landed in 6.1)
+        getport = util.getport
+
+    mailport = getport(ui.config(b'smtp', b'port', defaultport))
+
     ui.note(_(b'sending mail: smtp host %s, port %d\n') %
             (mailhost, mailport))
     s.connect(host=mailhost, port=mailport)
